Ultrasonic sensor

Dependents:   Obstacle_Avoiding_Robot wireless_project_BLE

Fork of HCSR04 by Prabhu Desai

Revision:
6:4be4fcd0c171
Parent:
4:33938a97d904
Child:
7:71da0dbf4400
--- a/hcsr04.h	Sat Mar 30 18:50:32 2013 +0000
+++ b/hcsr04.h	Sat Mar 30 18:52:13 2013 +0000
@@ -29,14 +29,14 @@
 /** Distance Measure Class(es)
  */
 
-class DistMeasure
+class HCSR04
 {
 public:
     /** Create a DistMeasure object connected to the specified pin
     * @param pin i/o pin to connect to
     */
-    DistMeasure(PinName TrigPin,PinName EchoPin);
-    ~DistMeasure();
+    HCSR04(PinName TrigPin,PinName EchoPin);
+    ~HCSR04();
 
     /** Return the distance from obstacle in cm
     * @param distance in cms and returns -1, in case of failure
@@ -29,14 +29,14 @@
 {
 public:
-    /** Create a DistMeasure object connected to the specified pin
+    /** Create a HCSR04 object connected to the specified pin
     * @param pin i/o pin to connect to
     */